#
# spec file for package wxWidgets-3_2
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor Qt%nil
%if "%flavor" == ""
# default flavor is GTK2
Name:           wxWidgets-3_2
%define pkgname wxWidgets-3_2
%define variant suse
%define gtk_version 2
%define toolkit gtk%gtk_version
%define base_packages 0
%bcond_with webview
%endif

%if "%flavor" == "GTK3"
Name:           wxGTK3-3_2
%define pkgname wxGTK3-3_2
%define variant suse
%define gtk_version 3
%define toolkit gtk%gtk_version
# build non-UI toolkit related packages
%define base_packages 1
%bcond_without webview
%endif

%if "%flavor" == "GTK3-nostl"
Name:           wxWidgets-3_2-nostl
%define pkgname wxWidgets-3_2-nostl
%define variant suse-nostl
%define gtk_version 3
%define toolkit gtk%gtk_version
%define base_packages 1
%bcond_with webview
%define extra_description This variant of wxWidgets is built without STL types (such as \
std::string), and is provided for old programs which fail to use e.g. \
wxString and instead rely on the wxChar pointer API.
%endif

%if "%flavor" == "Qt"
Name:           wxQt-3_2
%define pkgname wxQt-3_2
%define variant suse
%define toolkit qt
%define base_packages 0
%bcond_with webview
%endif

%define base_name wxWidgets-3_2
# Use default debug level, enabling exceptions
# Other valid values: yes/no/max
%define wx_debug %nil
%define psonum 5_0_0
%define sonum 5.0.0
Version:        3.1.5
Release:        150400.3.7.1
%define wx_minor 3.1
%define wx_micro 3.1.5
Summary:        C++ Library for Cross-Platform Development
License:        LGPL-2.1-or-later WITH WxWindows-exception-3.1
Group:          Development/Libraries/C and C++
URL:            https://www.wxwidgets.org/
Source:         https://github.com/wxWidgets/wxWidgets/releases/download/v%version/wxWidgets-%version.tar.bz2
Source2:        README.SUSE
Source5:        wxWidgets-3_2-rpmlintrc
# This script is not used during build, but it makes possible to
# identify and backport wxPython fixes to wxWidgets.
Source6:        wxpython-mkdiff.sh
# PATCH-FIX-OPENSUSE soversion.diff jengelh@inai.de -- Use the package version, not some incremental integer.
Patch0:         soversion.diff
# PATCH-FIX-OPENSUSE wxWidgets-3.1.5-fix-wxIcon-wxDVC-columns.patch boo#1187712 antoine.belvire@opensuse.org -- Fix poedit crashes when opening wxWidgets-3_2 files.
Patch1:         wxWidgets-3.1.5-fix-wxIcon-wxDVC-columns.patch
# PATCH-FIX-OPENSUSE wxWidgets-3_2-Create-our-own-socket-file-for-socket-file-test.patch qzhao@suse.com -- Create our own socket file for socket file test.
Patch2:         wxWidgets-3_2-Create-our-own-socket-file-for-socket-file-test.patch
# PATCH-FIX-OPENSUSE wxWidgets-3_2-fix-building-fault-S390.patch bsc#1217026 qzhao@suse.com -- Fix wxWidgets-3_2 building check fault on S390 platform.
Patch3:         wxWidgets-3_2-fix-building-fault-S390.patch
# PATCH-FIX-OPENSUSE wxWidgets-fix-redundant-decls.patch meissner@suse.com -- fix QT build, which includes assert.h twice
Patch4:		wxWidgets-fix-redundant-decls.patch
BuildRequires:  autoconf
BuildRequires:  cppunit-devel
BuildRequires:  gcc-c++
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  libSM-devel
BuildRequires:  libexpat-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmspack-devel
BuildRequires:  libnotify-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  zlib-devel
%if "%toolkit" == "gtk2"
BuildRequires:  gnome-vfs2-devel
BuildRequires:  gtk2-devel
%endif
%if "%toolkit" == "gtk3"
BuildRequires:  pkgconfig(gtk+-3.0)
%if %{with webview}
BuildRequires:  pkgconfig(webkit2gtk-4.0)
%endif
%endif
%if "%toolkit" == "qt"
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.1
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2.1
BuildRequires:  pkgconfig(Qt5OpenGL) >= 5.2.1
BuildRequires:  pkgconfig(Qt5Test) >= 5.2.1
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.1
BuildRequires:  pkgconfig(cairo)
%endif
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(liblzma)
%if 0%{?sle_version} < 150000 && !0%{?is_opensuse}
BuildRequires:  pkgconfig(sdl)
%else
BuildRequires:  pkgconfig(sdl2)
%endif
BuildRequires:  pkgconfig(xtst)

%description
wxWidgets is a C++ library abstraction layer for a number of GUI
backends. Applications can be created for different GUIs (GTK+,
Motif, MS Windows, MacOS X, Windows CE, GPE) from the same source
code.

%package -n libwx_base-%variant-devel
Summary:        Development files for %name
Group:          Development/Libraries/C and C++
Requires:       libwx_baseu-%variant%psonum = %version
Requires:       libwx_baseu_net-%variant%psonum = %version
Requires:       libwx_baseu_xml-%variant%psonum = %version
Provides:       libwx_base-devel
Conflicts:      libwx_base-devel

%description -n libwx_base-%variant-devel
wxWidgets is a C++ library abstraction layer for a number of GUI
backends.
This package is a build artifact and need not be manually installed.

%package -n libwx_baseu-%variant%psonum
Summary:        wxWidgets base library
# Name up to openSUSE 11.3 and up to wxGTK-2.8:
Group:          System/Libraries
Obsoletes:      wxGTK <= %version.0
# Third party base package name:
Obsoletes:      wxWidgets < %version
Provides:       wxWidgets = %version
Recommends:     wxWidgets-lang >= 3.0

%description -n libwx_baseu-%variant%psonum
Every wxWidgets application must link against this library. It
contains mandatory classes that any wxWidgets code depends on (e.g.
wxString) and portability classes that abstract differences between
platforms. wxBase can be used to develop console-only applications.
%{?extra_description}

%package -n libwx_baseu_net-%variant%psonum
Summary:        wxWidgets networking library
Group:          System/Libraries

%description -n libwx_baseu_net-%variant%psonum
Classes for network access with wxWidgets.

%package -n libwx_baseu_xml-%variant%psonum
Summary:        wxWidgets XML parser library
Group:          System/Libraries

%description -n libwx_baseu_xml-%variant%psonum
This library contains classes for parsing XML documents.

%package -n libwx_%{toolkit}u_adv-%variant%psonum
Summary:        wxWidgets advanced widgets and rarely-used widgets
Group:          System/Libraries

%description -n libwx_%{toolkit}u_adv-%variant%psonum
Advanced or rarely-used GUI classes for wxWidgets.

%package -n libwx_%{toolkit}u_aui-%variant%psonum
Summary:        wxWidgets advanced user interface docking library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_aui-%variant%psonum
The Advanced User Interface docking library of wxWidgets.

%package -n libwx_%{toolkit}u_core-%variant%psonum
Summary:        wxWidgets basic GUI class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_core-%variant%psonum
Basic GUI classes such as GDI classes or controls are in this
library. All wxWidgets GUI applications must link against this
library, only console mode applications need not.

%package -n libwx_%{toolkit}u_gl-%variant%psonum
Summary:        wxWidgets OpenGL integration library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_gl-%variant%psonum
This library contains the wxGLCanvas class for integration of OpenGL
with wxWidgets.

%package -n libwx_%{toolkit}u_html-%variant%psonum
Summary:        wxWidgets HTML parser and renderer library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_html-%variant%psonum
The wxHTML library provides classes for parsing and displaying HTML.
It is not intended to be a high-end HTML browser. wxHTML can be used
as a generic rich text viewer – for example, to display an About Box
or the result of a database search.
%{?extra_description}

%package -n libwx_%{toolkit}u_media-%variant%psonum
Summary:        wxWidgets media class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_media-%variant%psonum
wxMediaCtrl is a class for displaying types of media, such as videos,
audio files, natively through native codecs.

%package -n libwx_%{toolkit}u_propgrid-%variant%psonum
Summary:        wxWidgets property grid class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_propgrid-%variant%psonum
wxPropertyGrid is a specialized grid for editing properties, in other
words, name=value pairs.

%package -n libwx_%{toolkit}u_qa-%variant%psonum
Summary:        wxWidgets quality assurance class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_qa-%variant%psonum
This is the library containing extra classes for quality
assurance, containing the wxDebugReport class. wxDebugReport is
used to generate a debug report, containing information about the
program current state.

%package -n libwx_%{toolkit}u_ribbon-%variant%psonum
Summary:        wxWidgets's ribbon user interface library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_ribbon-%variant%psonum
The wxRibbon library is a set of classes for writing a ribbon user
interface.

%package -n libwx_%{toolkit}u_richtext-%variant%psonum
Summary:        wxWidgets Rich Text editor class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_richtext-%variant%psonum
wxRichTextCtrl provides a generic implementation of a rich text
editor that can handle different character styles, paragraph
formatting, and images. It is intended for "natural" text in the
sense that source code is better served by wxStyledTextCtrl.

%package -n libwx_%{toolkit}u_stc-%variant%psonum
Summary:        wxWidgets styled text class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_stc-%variant%psonum
A wxWidgets implementation of the Scintilla source code editing component.

%package -n libwx_%{toolkit}u_webview-%variant%psonum
Summary:        wxWidgets HTML/browser class library
Group:          System/Libraries

%description -n libwx_%{toolkit}u_webview-%variant%psonum
Library for a wxWidgets control that can be used to render web
(HTML / CSS / JavaScript) documents.

%package -n libwx_%{toolkit}u_xrc-%variant%psonum
Summary:        wxWidgets's XML-based resource system
Group:          System/Libraries

%description -n libwx_%{toolkit}u_xrc-%variant%psonum
The XML-based resource system of wxWidgets, known as XRC, allows user
interface elements such as dialogs, menu bars and toolbars, to be
stored in text files and loaded into the application at run-time.

%package -n %{base_name}-plugin-sound_sdlu-3_2
Summary:        wxWidgets SDL Plugin
Group:          System/Libraries

%description -n %{base_name}-plugin-sound_sdlu-3_2
SDL based sound plugin for the wxWidgets cross-platform GUI.

%package devel
Summary:        Development files for %name
Group:          Development/Libraries/C and C++
%if "%toolkit" == "gtk2"
Requires:       gtk2-devel
%endif
%if "%toolkit" == "gtk3"
Requires:       pkgconfig(gtk+-3.0)
%endif
%if "%toolkit" == "qt"
Requires:       pkgconfig(Qt5OpenGL) >= 5.2.1
Requires:       pkgconfig(Qt5Widgets) >= 5.2.1
%endif
Requires:       libwx_%{toolkit}u_adv-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_aui-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_core-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_gl-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_html-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_media-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_propgrid-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_qa-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_ribbon-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_richtext-%variant%psonum = %version
Requires:       libwx_%{toolkit}u_stc-%variant%psonum = %version
%if %{with webview}
Requires:       libwx_%{toolkit}u_webview-%variant%psonum = %version
%endif
Requires:       libwx_%{toolkit}u_xrc-%variant%psonum = %version
Requires:       libwx_base-%variant-devel = %version
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glu)
Provides:       wxWidgets-any-devel
Conflicts:      wxWidgets-any-devel
%if "%toolkit" == "gtk2"
Provides:       wxGTK2-devel = %version-%release
Provides:       wxWidgets-devel = %version-%release
# Name up to openSUSE 11.3 and up to wxGTK-2.8.x:
Provides:       wxGTK-devel = %version-%release
Obsoletes:      wxGTK-devel < %version-%release
%endif
%if "%toolkit" == "gtk3"
%if "%flavor" != "GTK3-nostl"
Provides:       wxGTK3-devel = %version-%release
%endif
%endif
%if "%toolkit" == "qt"
Provides:       wxQt-devel = %version-%release
%endif

%description devel
wxWidgets is a C++ library abstraction layer for a number of GUI
backends. Applications can be created for different GUIs (GTK+,
Motif, MS Windows, MacOS X, Windows CE, GPE) from the same source
code.

This package contains all files needed for developing with %name.
%{?extra_description}

Note: wxWidgets variant devel packages are mutually exclusive. Please
read %_docdir/%name/README.SUSE to pick a correct variant.

%prep
%autosetup -n wxWidgets-%version -p1
cp %{S:2} .

%build
autoconf -f -i
# NOTE: gnome-vfs is deprecated. Disabled for GTK3 build
#
# With 2.9.1:
# --enable-objc_uniquifying is relevant only for Cocoa
# --enable-accessibility is currently supported only in msw
# --enable-extended_rtti does not compile

%configure \
	--enable-vendor=%variant \
%if "%toolkit" == "qt"
	--with-qt \
%else
	--with-gtk=%gtk_version \
%if "%gtk_version" == "2"
	--with-gnomevfs \
%endif
%endif
	--enable-unicode \
	--with-opengl \
	--with-libmspack \
	--with-sdl \
	--enable-ipv6 \
	--enable-mediactrl \
	--enable-optimise \
	%{wx_debug:--enable-debug=%{wx_debug}} \
        --enable-repro-build \
        --disable-glcanvasegl \
%if "%flavor" == "GTK3-nostl"
	--disable-stl \
	--disable-plugins
%else
	--enable-stl \
	--enable-plugins
%endif

%make_build

%install
export VENDORTAG='-$variant' # only needed for non-MSW
%make_install
%if !%base_packages
# Drop libraries already supplied by another packages
rm -fv "%buildroot/%_libdir"/libwx_baseu*.so* \
	"%buildroot/%_libdir/wx/%wx_micro"/sound_sdlu-*.so
%endif
rm -Rfv %buildroot/%_datadir/locale

# HACK: Fix wx-config symlink (bug introduced in 2.9.4).
ln -sf $(echo %buildroot/%_libdir/wx/config/* | sed "s%%%buildroot%%%%") %buildroot/%_bindir/wx-config

%check
%if "%{flavor}" != "doc"
%make_build -C tests all
pushd tests
# Disable webrequest tests requiring network access
export WX_TEST_WEBREQUEST_URL=0
# Non-gui tests
./test -l || true
# ExecTestCase depends on xclock, and is fragile
./test exclude:ExecTestCase exclude:[.]
# Tests depending on a running X server
# ./test_gui -l || true
%endif

%post   -n libwx_baseu-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_baseu-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_baseu_net-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_baseu_net-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_baseu_xml-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_baseu_xml-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_adv-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_adv-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_aui-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_aui-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_core-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_core-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_gl-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_gl-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_html-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_html-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_media-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_media-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_propgrid-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_propgrid-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_qa-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_qa-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_ribbon-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_ribbon-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_richtext-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_richtext-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_stc-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_stc-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_webview-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_webview-%variant%psonum -p /sbin/ldconfig
%post   -n libwx_%{toolkit}u_xrc-%variant%psonum -p /sbin/ldconfig
%postun -n libwx_%{toolkit}u_xrc-%variant%psonum -p /sbin/ldconfig

%if %base_packages
%files -n libwx_base-%variant-devel
%_libdir/libwx_baseu*.so

%files -n libwx_baseu-%variant%psonum
%_libdir/libwx_baseu-%variant.so.%{sonum}*

%files -n libwx_baseu_net-%variant%psonum
%_libdir/libwx_baseu_net-%variant.so.%{sonum}*

%files -n libwx_baseu_xml-%variant%psonum
%_libdir/libwx_baseu_xml-%variant.so.%{sonum}*
%endif

%files -n libwx_%{toolkit}u_adv-%variant%psonum
%_libdir/libwx_%{toolkit}u_adv-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_aui-%variant%psonum
%_libdir/libwx_%{toolkit}u_aui-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_core-%variant%psonum
%_libdir/libwx_%{toolkit}u_core-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_gl-%variant%psonum
%_libdir/libwx_%{toolkit}u_gl-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_html-%variant%psonum
%_libdir/libwx_%{toolkit}u_html-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_media-%variant%psonum
%_libdir/libwx_%{toolkit}u_media-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_propgrid-%variant%psonum
%_libdir/libwx_%{toolkit}u_propgrid-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_qa-%variant%psonum
%_libdir/libwx_%{toolkit}u_qa-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_ribbon-%variant%psonum
%_libdir/libwx_%{toolkit}u_ribbon-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_richtext-%variant%psonum
%_libdir/libwx_%{toolkit}u_richtext-%variant.so.%{sonum}*

%files -n libwx_%{toolkit}u_stc-%variant%psonum
%_libdir/libwx_%{toolkit}u_stc-%variant.so.%{sonum}*

%if %{with webview}
%files -n libwx_%{toolkit}u_webview-%variant%psonum
%_libdir/libwx_%{toolkit}u_webview-%variant.so.%{sonum}*
%dir %_libdir/wx
%dir %_libdir/wx/%wx_micro
%_libdir/wx/%wx_micro/web-extensions/
%endif

%files -n libwx_%{toolkit}u_xrc-%variant%psonum
%_libdir/libwx_%{toolkit}u_xrc-%variant.so.%{sonum}*

%if %base_packages
%if "%flavor" != "GTK3-nostl"
%files -n %{base_name}-plugin-sound_sdlu-3_2
%dir %_libdir/wx
%dir %_libdir/wx/%wx_micro
%_libdir/wx/%wx_micro/sound_sdlu-%wx_micro.so
%endif
%endif

%files devel
# Complete documentation is available in the docs packages.
%doc docs/*.txt README.SUSE
%_bindir/wxrc
%_bindir/wxrc-%wx_minor
%_bindir/*-config*
%_datadir/aclocal
%_datadir/bakefile
%_includedir/wx-%wx_minor
%_libdir/*.so
%if %base_packages
%exclude %_libdir/libwx_baseu*
%endif
%dir %_libdir/wx
%_libdir/wx/config
%_libdir/wx/include

%changelog
* Wed Feb 14 2024 meissner@suse.com
- wxWidgets-fix-redundant-decls.patch: disable for now to make it build
* Thu Dec 28 2023 qzhao@suse.com
- Add wxWidgets-3_2-fix-building-fault-S390.patch:
  Fix wxWidgets-3_2 building check fault on S390 platform:
  /sys/power/state doesn't exist in SLE S390 platform and certain
  types of containers, so check the file exist before run the
  test case.
  (bsc#1217026)
* Tue Apr 12 2022 qzhao@suse.com
- Add wxWidgets-3_2-Create-our-own-socket-file-for-socket-file-test.patch:
  Backporting f172f53a from upstream to fix building check fault:
  Create our own socket file for socket file test, /dev/log doesn't
  exist in certain types of containers.
  (bsc#1217026)
* Sat Aug 21 2021 badshah400@gmail.com
- Disable building with EGL support: glew is not ready for EGL yet
  and this causes wxWidgets based OpenGL apps (e.g. hugin) to
  crash. See boo#1188519, boo#1189524.
* Fri Jun 25 2021 antoine.belvire@opensuse.org
- Add wxWidgets-3.1.5-fix-wxIcon-wxDVC-columns.patch:
  Fix poedit crashes when opening wxWidgets-3_2 files.
  (boo#1187712)
* Sun Jun  6 2021 antoine.belvire@opensuse.org
- Update to version 3.1.5:
  * New wxWebRequest and related classes provide a simple way to
    use HTTPS and HTTP/2 from wxWidgets applications using native
    libraries or libcurl.
  * Support EGL in wxGLCanvas and Wayland in wxMediaCtrl under
    Linux.
  * Many appearance and other fixes for macOS 11.
  * More improvements to wxGrid UI, API and performance.
  * wxImage improvements: add alpha support in Paste() and
    clipboard support.
  * API additions: wxPersistentComboBox, wxFileName::ResolveLink(),
    wxFileHistory::SetMenuPathStyle(), wxString::utf8_string(),
    wxEVT_FULLSCREEN.
  * Improvements: wxConfig now supports 64-bit integers, wxLog uses
    millisecond resolution in timestamps, XRC files can be loaded
    from URLs.
  * Yet more bug fixes, fixes for API inconsistencies and
    optimizations, notably in wxDataViewCtrl, wxListCtrl,
    wxPropertyGrid.
- Remove patches fixed upstream:
  * 0001-Don-t-use-wxASCII_STR-inside-wxART_MAKE_XXX_ID-macro.patch.
  * 0002-Fix-documented-type-of-wxART_XXX-constants.patch.
* Mon Nov 16 2020 jengelh@inai.de
- Fix an rpmlint warning by moving libwx_base symlinks to their
  own -devel subpackage which is then required by
  (wxWidgets-devel, wxGTK3-devel).
* Fri Oct  9 2020 jengelh@inai.de
- Change wxGTK2 flavor to be the main (unnamed) flavor.
* Fri Oct  9 2020 stefan.bruens@rwth-aachen.de
- Fix unquoted bareword comparisons for RPM 4.16 compatibility
* Wed Sep 30 2020 stefan.bruens@rwth-aachen.de
- Fix wxPython compatibility issue:
  Add 0001-Don-t-use-wxASCII_STR-inside-wxART_MAKE_XXX_ID-macro.patch
  Add 0002-Fix-documented-type-of-wxART_XXX-constants.patch
* Wed Aug 19 2020 stefan.bruens@rwth-aachen.de
- Use _multibuild to avoid changes and spec files of the variants
  getting out of sync.
* Sun Jul 26 2020 stefan.bruens@rwth-aachen.de
- Do not disable debugging completely, only recommended for
  constrained environments and breaks wxPython tests
- Correct base_packages flag for nostl variant, it can not use the
  base libraries of the regular variant
- Build base libraries from wxGTK3 build, wxWidgets (GTK2) is no
  longer used by any Factory package.
* Sat Jul 25 2020 stefan.bruens@rwth-aachen.de
- Update to new upstream release 3.1.4:
  * Incompatible to 3.1.3: CMake library targets were renamed and
    now start with 'wx'. In addition, aliases for the libraries
    have been added using the 'wx::' namespace. For example, the
    core library is now named wxcore and has alias wx::core.
  * Add natural sort functions.
  * Add wxTempFFile class (Dummy).
  * Fix bug with multiple leading ".." in wxFileName::Normalize().
  * Improve brush transparency support in wxSVGFileDC.
  * Optionally forbid implicit wxString/char* conversions.
  * Add support for wxGenericAnimationCtrl to XRC.
  * Add wxDD_SHOW_HIDDEN and wxDD_MULTIPLE wxDirDialog flags.
  * Add wxWebView::SetZoomFactor(float).
  * Add wxWindow::DisableFocusFromKeyboard().
  * Allow overriding wxDataViewModal::HasValue().
  * Call wxAuiManager::UnInit() automatically now.
  * Fix crash and layout problem in wxGenericDirCtrl
  * wxQt: Fix build with Qt 5.15
  * GTK backend:
  * Add native wxSearchCtrl implementation.
  * Implement wxBU_EXACTFIT support in wxButton.
  * Fix a regression with crashes when using wxBufferedPaintDC.
  * Fix drawing bitmaps with masks using wxGraphicsContext under
    GTK2.
  * Fix position of popup menus on non-primary display.
  * Make wxUIActionSimulator much more reliable
  * Fix caret colour in wxTextCtrl with custom colours.
- Drop obsolete patches:
  * 0001-Add-missing-QPainterPath-include-required-with-Qt-5..patch
  * 0002-Make-the-wxUIActionSimulator-Text-implementation-mat.patch
* Tue Jun 16 2020 davejplater@gmail.com
- Build nostl package against gtk3, audacity crashes with gtk2
* Tue Jun  9 2020 davejplater@gmail.com
- Add nostl package for audacity
* Mon Jun  1 2020 stefan.bruens@rwth-aachen.de
- Fix wxQt build with Qt 5.15, add
  0001-Add-missing-QPainterPath-include-required-with-Qt-5..patch
- Make liblzma build dependency explicit, to have the same feature
  set on all flavors.
- Fix wrong function signature causing build failures in
  python-wxPython, add:
  0002-Make-the-wxUIActionSimulator-Text-implementation-mat.patch
* Fri May 29 2020 stefan.bruens@rwth-aachen.de
- Add explicit libXtst build dependency, required for Leap 15.1
  (already implicit on Leap 15.2 and TW).
* Thu May 28 2020 stefan.bruens@rwth-aachen.de
- Update to new upstream release 3.1.3
  For a detailed changelog, see
  https://raw.githubusercontent.com/wxWidgets/wxWidgets/v3.1.3/docs/changes.txt
  * Support for per-monitor DPI and dynamic DPI changes under MSW.
  * More generally, many fixes for various controls appearance in high DPI.
  * Long requested support for freezing rows and/or columns in wxGrid.
  * New XRC handlers for wxDataViewCtrl, wxInfoBar.
  * It is now possible to use gradients when creating wxGraphicsPen.
  * Extended compiler (MSVS 2019) and platforms (macOS 10.14+) support.
  * Significant improvements to the (still experimental) wxQt port.
  * Important bug fixes for focus handling in wxOSX port.
- Cleanup spec file
- Enable reproducible-build option
- Use SDL2 instead of SDL1 (only used by sound plugin)
* Mon Apr 15 2019 jengelh@inai.de
- Update to new snapshot 3.1.3~g673 (6cc1d63d)
  * Graphics context methods for the Qt platform
- Enabled webkit2 backend for wxWebView (wxGTK3 only) [boo#1107337]
* Fri Jan 11 2019 martin.koegler@chello.at
- Update to new upstream release 3.1.2
  * Support for non-integer font sizes and arbitrary font
    weights.
  * New wxLZMA{Input,Output}Stream classes.
  * Add wxDataViewToggleRenderer::ShowAsRadio(),
    wxDisplay::GetPPI(), wxGrid::SetCornerLabelValue(),
    wxHtmlEasyPrinting::SetPromptMode(),
    wxJoystickEvent::GetButtonOrdinal(),
    wxToolbook::EnablePage().
- Remove wxqt-compile.diff (no longer needed)
* Tue Apr 17 2018 jengelh@inai.de
- Update soversion.diff to use the package version, not some
  incremental integer.
* Mon Feb 19 2018 jengelh@inai.de
- Update to new upstream release 3.1.1
  * wxRibbonButtonBar::DeleteButton() now deletes and not just
    removes the button.
  * Using invalid flags with wxBoxSizer or wxGridSizer items now
    triggers asserts
  * wxWS_EX_VALIDATE_RECURSIVELY is now the default behaviour.
  * wxListCtrl::HasCheckboxes() and EnableCheckboxes(), which
    were added in 3.1.0, have been renamed to HasCheckBoxes and
    EnableCheckBoxes respectively for consistency with wxCheckBox
    naming.
  * wxZipOutputStream will now automatically convert filenames to
    UTF-8, if the wxMBConv used when calling the constructor
    supports UTF-8 encoding.
* Sat Feb 17 2018 martin.koegler@chello.at
- Update to 3.1.1-rc (3.1.1~2807)
* Wed Jan 24 2018 jengelh@inai.de
- Rework provides/conflicts between -devel variants.
- Update to new development snapshot 3.1.1~2640
  * Support for multi-touch gestures
  * Implement persistence for wxDataViewListCtrl
  * Rename all objects to "DataViewCtrl" and "DVC" instead of
    "DataViewListCtrl" and "DVLC" to reflect the change of
    implementation at the base class.
* Fri Dec 15 2017 jengelh@inai.de
- Add a recommends from the wx base library to the language package.
* Sat Oct 21 2017 martin.koegler@chello.at
- Unify packaging
- Drop webkit as in wx3.0 packages
- Fix Qt build errors
* Sun Oct 15 2017 kamikazow@opensuse.org
- Disable WebView for TW and upcoming Leap 15.
* Fri Jul 22 2016 mailaender@opensuse.org
- Update to new upstream development release 3.1.0
  * Many improvements for high DPI monitors support, notably XRC now interprets
  all pixel values as being in resolution-independent pixels.
  * wxQt branch implementing Qt5-based port of wxWidgets API was merged into
  the trunk (Mariano Reingart, Google Summer of Code project).
  * Added wxNativeWindow allowing to embed native widgets in wxWidgets programs.
  * Improve wxGLCanvas to be more type safe and better support modern OpenGL.
* Fri Nov  7 2014 jengelh@inai.de
- Update to new upstream release 3.0.2
  * Fix silent data loss in wx[F]File::Write(wxString) if conversion
  fails.
  * Make wxString::FromCDouble() work when the global C++ locale is
  not the C one.
  * Fix mouse handling in wxNotebook containing wxListCtrl.
- Bump SONAME due to changed ABI, add soversion.diff.
- Don't let wxGTK3-3_0.spec build the SDL plugin (already done
  by wxWidgets-3_0.spec)
* Thu Nov  6 2014 jengelh@inai.de
- Restore libwx_base*.so devel symlinks [boo#904098]
* Wed Nov  5 2014 jengelh@inai.de
- Replace broad Requires: Mesa-devel by pkgconfig(gl)
  [Mesa-libGL-devel]
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Wed Jul 16 2014 jengelh@inai.de
- Remove the mechanism to support different variants, as it does
  not support concurrent presence of multiple variants.
- Remove wxWidgets-3_0-config-force-rpath.patch,
  wxWidgets-find-wx-provides-bash3.patch (no longer needed)
* Mon Jun 16 2014 jengelh@inai.de
- Update to new upstream release 3.0.1
  * wxHTML displays tables much faster now.
  * Double clicking wxGrid columns does not make them too small
  any more.
  * Fix bugs when dragging columns in wxGrid with hidden columns.
  * Loading ICO files with PNG data is now supported.
  * Mouse wheel scrolling in wxListCtrl works again.
  * wxStaticBoxSizer contents is not truncated any more.
  * AUI panels may now be re-docked after floating them.
- Remove wxWidgets-3_0-fixGTK3-build.patch (no longer needed)
* Wed Jun 11 2014 fcrozat@suse.com
- Add _constraints file to ensure enough disk space is available
  for build.
* Mon Jun  9 2014 jengelh@inai.de
- Revert the GTK3 change (there are rendering problems).
  wxWidgets-3_0(-devel) is now wxGTK2 again, and the wxGTK3 backend
  is available in wxGTK3(-devel).
* Fri Jun  6 2014 jengelh@inai.de
- Continue to provide a wxGTK2 build in parallel to wxGTK3
  (new specfile wxGTK2-3_0.spec; use BuildRequire wxGTK2-devel)
- Remove unused wxcontainer and wxcontainer26c subpackage logic
  plus spec files
- Let /usr/lib(64)/wx be owned by packages that put files there
* Fri Jun  6 2014 fcrozat@suse.com
- Switch build to GTK3 for SLE12 and openSUSE > 13.1
- Add wxWidgets-3_0-fixGTK3-build.patch: fix build with recent GTK3
  (from upstream)
- Remove libgnomeprintui dependencies, GTK printing support is now
  used.
- Disable gnomevfs support when building GTK3 version.
- Add/fix missing BuildRequires: xorg-x11-libSM-devel,
  libnotify-devel.
- Do not build webview on SLE10 and SLE11
* Thu Jun  5 2014 jengelh@inai.de
- Use system libraries instead of bundled versions:
  libjpeg, libpng, zlib
- Enable use of libSM
* Fri Apr 25 2014 jengelh@inai.de
- Remove unused "ansi" configuration: wxWidgets 3 in Unicode mode
  supports both char* and wchar_t*.
* Tue Mar 11 2014 jengelh@inai.de
- Exclude libwx_webview from SLE11 build
* Mon Feb 17 2014 seiler@b1-systems.de
- added baselibs.conf to provide *-32bit packages
* Fri Feb  7 2014 jengelh@inai.de
- Remove seemingly pointless patch wxGTK-enable-wxrc.patch.
  wxrc is built and installed in any case.
* Thu Jan 30 2014 jengelh@inai.de
- Patches wxGTK-enable-wxrc.patch,
  wxWidgets-3_0-config-force-rpath.patch,
  wxWidgets-find-wx-provides-bash3.patch were inherited from
  wxWidgets-2_8 package but never mentioned in any package.
  Here is a mention.
* Thu Nov 14 2013 jengelh@inai.de
- Update to new upstream release 3.0.0
  * wxWidgets is now always built with Unicode support but provides
  the same simple (i.e. "char *"-tolerant) API as was available
  in ANSI build in the past.
  * wxWidgets may now use either wchar_t (UTF-16/32) or UTF-8
  internally, depending on what is optimal for the target
  platform.
  * New webview library, implementing wxWebView: a wrapper for the
  native platform web engine with full support for HTML and
  JavaScript.
  * New propgrid library containing wxPropertyGrid and related
  classes.
  * New ribbon library for advanced toolbars.
  * Event loops, timers and sockets can now be used in wxBase,
  without GUI.
  * Events can now be connected to any functor, not necessarily a
  method of wxEvtHandler-derived class. The compile-time safety
  was also improved.
  * Documentation for wxWidgets has been converted from LaTex to
  C++ headers with Doxygen comments and significantly improved in
  the process (screenshots of various controls were added, more
  identifiers are now linked to their definition &c).
  * Support for persistent objects automatically saving and
  restoring their state was added.
- Drop wxWidgets-to-wxpython-2.9.4.0.patch (merged upstream)
* Thu Aug 22 2013 jengelh@inai.de
- Use %%_smp_mflags for parallel build and better make install call.
* Thu Apr 11 2013 fisiu@opensuse.org
- Build wxWidgets with webview support.
* Thu Oct 25 2012 sbrabec@suse.cz
- Provide wxWidgets-3_0*-devel for future compatibility.
- Add "API version" in %%description.
- Backported fixes from 2.8 branch.
- Included post-release fixes from wxpython.
* Thu Sep 20 2012 coolo@suse.com
- add explicit buildrequire on pkgconfig(glu)
* Mon Jul 23 2012 sbrabec@suse.cz
- Fixed wx-config symlink (bnc#772528).
* Thu Jul 19 2012 sbrabec@suse.cz
- Update to version 2.9.4.
* Fri Apr 27 2012 sbrabec@suse.cz
- Backported fixes of the dependency generator from 2.8 branch
  (bnc#757124, bnc#759287#c3).
* Thu Apr 19 2012 sbrabec@suse.cz
- Added support for Fedora compatible 24c variants (bnc#660438).
- Change name of compat-lib-config virtual provide to not clash
  with package name, fix requires/provides generator (bnc#757124).
* Mon Apr  2 2012 sbrabec@suse.cz
- Update to version 2.9.3.
* Wed Dec 21 2011 coolo@suse.com
- own aclocal directory, there is no other reason to buildrequire
  automake
* Mon Oct 17 2011 coolo@suse.com
- fix whitespace of spec file
* Wed Aug  3 2011 sbrabec@suse.cz
- Updated to version 2.9.2.
* Tue Jul 26 2011 aj@suse.de
- Recommend instead of require lang package.
* Tue May 17 2011 sbrabec@suse.cz
- Create synthetic .la files to work-around libtool failures when
  linking third level libraries or binaries (bnc#690952).
* Fri Apr  8 2011 sbrabec@suse.cz
- Do not use bash coproc on system with bash-3.
* Tue Mar 29 2011 sbrabec@suse.cz
- Fixed find-wx-requires to check directories instead of library
  name. Provide find-wx-provides. (bnc#681409)
* Thu Dec 23 2010 sbrabec@suse.cz
- Updated to version 2.9.1.
- Rename package to wxWidgets to follow upstream base name.
- Split wxPython documentation to a separate package.
- Build Unicode/ANSI, standard/debug and STL/wx container versions
  separately.
- Spec file completely rewritten.
* Sun Aug 15 2010 termim@gmail.com
-  Updated to version 2.8.11.0
  Adds Python 2.7 builds, PySlices, new pubsub implementation,
  lots of updates to AGW, and lots of bugs fixed.
-  Removed wxGTK-GSocket-clash.patch and wxGTK-editra-ebmlib.patch
  as already fixed.
* Tue Jun 15 2010 sbrabec@suse.cz
- Added --enable-graphics_ctx to fix Editra (bnc#580060).
- Added ebmlib file required by Editra (bnc#580060,
  patch from Salix).
* Mon Feb 22 2010 crrodriguez@opensuse.org
- build with PIC
* Thu Jan 28 2010 sbrabec@suse.cz
- Enabled media libraries (bnc#565039).
* Fri Sep 25 2009 sbrabec@suse.cz
- Disabled STL (bnc#530027). See also
  http://lists.opensuse.org/opensuse-factory/2009-09/msg00386.html
- Removed obsolete RPATH.
- The GSocket symbol clash fix replaced by the upstream one.
* Thu Sep 17 2009 matejcik@suse.cz
- fixed pth file to point to platlib
* Sat Sep  5 2009 sbrabec@suse.cz
- Fixed for the latest python package.
* Fri Aug  7 2009 sbrabec@suse.cz
- Updated to version 2.8.10.1:
  * Incompatible change in wxTreeCtrl behaviour!
  * Added several functions forward compatible with wxWidgets 3.0.
  * Add wxBU_EXACTFIT support to wxToggleButton XRC handler.
  * wxHashMap::insert() doesn't update the value if it didn't
    insert the element any more.
  * Correct bug in wxTimeSpan::Format() for negative spans.
  * Correct several bugs in wxList using end() iterators.
  * Translation updates.
  * Fix wxURL::GetInputStream() for URLs with special characters in
    credentials.
  * Fix wxURI::GetUser() for URIs without password.
  * Correct wxDateTime DST computation for 2006 and later.
  * wxRTC: fixed a problem with HTML list generation.
  * wxRTC: no longer deletes a character when content is selected
  before pressing Delete.
  * wxRTC: fixed inability to select no superscript and no
  subscript in formatting dialog.
  * wxRTC: fixed centering and right-justification when combined
    with left indentation.
  * wxRTC: fixed lack of right margin when centering or
    right-justifying.
  * wxRTC: fixed wrong descent when wrapping lines with different
    font sizes.
  * wxRTC: fixed wrapping problem for long lines.
  * wxRTC: all buffer margins now respected.
  * wxRTC: Added wxRE_CENTRE_CARET to centre the caret line
    vertically.
  * Fixed wxHTML's pagebreaks computation in tables.
  * Fixed wxHtmlWindow::SelectionToText() to correctly insert
    newlines after single-cell paragraphs.
  * Fixed wxHTML's line breaks handling in <pre> blocks.
  * wxHTML: don't include extra whitespace in table cells.
  * Implemented wxWindow::DragAcceptFiles() on all platforms.
  * Added wxAUI_MGR_LIVE_RESIZE flag to wxAuiManager.
  * Use bitmap mask in wxSplashScreen.
  * Translate "(c)" and "(C)" to the real copyright sign in
    wxAboutBox.
  * Fix painting of highlight border for merged cells in wxGrid.
  * Fix handling of long lines in wxGridCellAutoWrapStringRenderer.
  * Return false from wxSingleInstanceChecker::IsAnotherRunning()
    if an error occurred while opening or reading the lock file.
  * Fixed printing to use fonts sizes adjustment consistent with
    wxMSW.
  * Make colours used by list, tree and status bar controls more
    consistent with the system theme settings.
  * Worked around bug in GTK+ < 2.14 where enabling some controls
    such as wxButton didn't re-enable sensitivity until the mouse
    was moved.
* Thu Jun 18 2009 sbrabec@suse.cz
- Worked-around GSocket name conflict with GIO.
* Tue Feb 17 2009 crrodriguez@suse.de
- build require libexpat-devel so we dont use the bundled one
* Wed Feb  4 2009 pth@suse.de
- Disable the use of precompiled headers as the way wxWidgets uses
  them is not supported by current GCC.
* Tue Feb  3 2009 pth@suse.de
- Update to 2.8.9.1:
  * Optimize wxString::Replace() for single character arguments.
  * Updated Hindi translation.
  * Use tr1::unordered_{map,set} for wxHash{Map,Set} implementation if available
    in STL build; in particular do not use deprecated hash_{map,set} which
    results in a lot of warnings from newer g++.
  * Added support for reading alpha channel in BMP format.
  * Fixed help viewer bug whereby the splitter sash in wxHtmlHelpWindow could
    go underneath the left-hand pane, permanently, after resizing the
    help window.
  * Fixed wxHTML default font size for printing to be 12pt regardless of the
    platform, instead of depending on GUI toolkit's screen configuration.
  * Support wxDP_ALLOWNONE style in generic wxDatePickerCtrl version.
  * Set wxKeyEvent::m_uniChar correctly in the events generated by generic
    wxListCtrl.
  * Fix changing size of merged cells in wxGrid.
  * Fixed wrapping bug in wxRichTextCtrl when there were images present;
    now sets the cursor to the next line after pressing Shift+Enter.
  * Fixed Cmd+Back, Cmd+Del word deletion behaviour in wxRichTextCtrl.
  * Fix crash when reading malformed PCX images.
  * Fix bug with wrong transparency in GIF animations.
  * Store palette information for XPM images in wxImage.
  * Fixed selection bugs and auto list numbering in wxRichTextCtrl.
  * Significantly optimize wxGrid::BlockToDeviceRect() for large grids.
  * Introduced new wxAuiToolBar class for better integration and look-and-feel.
  * Fix a crash in wxAuiFrameManager when Update() was called in between mouse-up
    and mouse-down events
  * wxAUI: added various NULL-ptr asserts.
  * Fixed problem with Floatable(false) not working in wxAuiFrameManager.
  * Fixed maximize bug in wxAUI.
  * Allow period in link anchors in wxHTML.
  * Fixed memory corruption in wxHTML when parsing "&;" in the markup.
  * Fixed event type in EVT_GRID_CMD_COL_MOVE and EVT_GRID_COL_MOVE.
  * wxGrid doesn't steal focus when hiding editor any more.
  * MIME types reading fixed when running under GNOME, reading .desktop
    files and also the default application list.
  * Added filesys.no-mimetypesmanager system option so that applications that
    must load an XRC file at program startup don't have to incur the
    mime types manager initialization penalty.
  * Fixed masking of disabled bitmaps in wxMenuItem and wxStaticBitmap.
  * Fixed generation of events for an initially empty wxDirPickerCtrl.
  * Fixed detection of Meta key state so that NumLock isn't misdetected
    as Meta (requires GTK+ 2.10).
  * Fix changing font/colour of label in buttons with images.
- Make funtion return a value.
* Wed Sep  3 2008 sbrabec@suse.cz
- Updated to version 2.8.8.1:
  * many API-compatible fixes and improvements, see
    docs/changes.txt for complete list
* Mon Sep  1 2008 sbrabec@suse.cz
- Dropped obsolete ODBC support (bnc#397044).
* Fri May  2 2008 sbrabec@suse.cz
- Don't unload libgnomevfs-2.so.0 on exit (bnc#380267).
- Removed obsolete configure options (bnc#380267#c7).
* Fri Mar 28 2008 sbrabec@suse.cz
- Updated to version 2.8.7.1:
  * many API-compatible crash fixes, improvements and other fixes,
    see docs/changes.txt for complete list
* Tue Oct  2 2007 sbrabec@suse.cz
- Updated to version 2.8.6.0:
  * many API-compatible crash fixes, improvements and orger fixes,
    see docs/changes.txt for complete list
  * fixed bugs and inconsistencies in wxWidgets and wxPython
* Thu Sep 13 2007 prusnak@suse.cz
- corrected last patch (gtk_border_free.patch) [#294693]
* Wed Sep  5 2007 bwalle@suse.de
- fix crash on startup on x86_64 (#294693)
* Wed Aug 29 2007 prusnak@suse.cz
- pack non-unicode libraries as wxGTK-compat package (again)
- run ldconfig in post/postun scriptlets
* Wed May 23 2007 prusnak@suse.cz
- update to 2.8.4.0
  * changes are too numerous to list, see changes.txt for full list
- drop non-unicode libraries (not used anymore)
- cleaned spec file
* Mon Mar  5 2007 pth@suse.de
- Don't hardcode lib64 in .spec file.
- Replace contrib/samples/applet/monitors.c once again (see #203607).
* Thu Mar  1 2007 pth@suse.de
- Update to 2.8.1.1. Changes are too numerous to list, see
  changes.txt for a full list.
- fix use of uninitialised variables wxPython_int.h
- Correct spelling in README.unicode
* Mon Dec 11 2006 sbrabec@suse.cz
- Source code cleanup (#226403).
* Tue Sep  5 2006 sbrabec@suse.cz
- Repackaged without undistributable monitors.c (#203607).
* Mon Aug  7 2006 sbrabec@suse.cz
- Updated to version 2.6.3.3 (#162198):
  * Fixed crash when loading message catalogs in Unicode build.
  * Fixed crash in wxList code when building with wxUSE_STL=1
  * Spurious error message from wxLaunchDefaultBrowser fixed.
  * Compilation fixes for (more strict) g++ 4.1
  * Speed improvements to wxRegEx
  * Fix regerror and regfree name conficts
  * wxCondition::WaitTimeout() now returns correct value
  * Bug in wxLogStream::DoLogString in Unicode builds fixed
  * wxFileName now also looks for TMPDIR on Unix
  * Fixed occasional wxThread cleanup crash
  * wxImage::Copy() forgot the alpha channel
  * Fixed wxSocketBase::InterruptWait on wxBase
  * wxSocket::_Read continues reading from socket after exhausting
    pushback buffer
  * Fixed abort() on loading invalid PNG image
  * Added space after list item number in wxHTML
  * wxCalendarCtrl drawing, positioning and hit-testing fixes
  * More checking of image validity before loading into wxImage
  * Added double-buffering to wxVListBox and fixed scrolling
  * More than one filter allowed in in wxDocTemplate filter
  * Fixed infinite loop in tab traversal code with wxUSE_STL==1
  * In wxScrolledWindow:DoGetBestSize, no longer adds difference
    between client and total size
  * Fixed problem with zoom setting in print preview
  * Fixed problem with choice editor in wxGrid
  * Fixed problem trying to print from a preview
  * Polygon and line drawing speeded up if there is no scaling
  * Fixed problems with CJK input method (reverted)
  * Fixed wxNotebook::HitTest when the leftmost visible tab is not
    the actual first tab
  * Send wxSetCursorEvent
  * Fix RequestMore for idle events
  * Implement user dashes for PS and GNOME printing
  * Correct update region code
  * Change wxMimeTypesManager code to just read the MIME-types
  * Speed up reading MIME database
  * wxClipboard fixes
  * Support underlined fonts in wxTextCtrl
  * wxWindow and wxScrolledWindow now generate all scroll events
  * Implemented wxToggleButton
  * Fixed wxDb::DBMS() indicating DB2 dBase databases
  * Fixed buffer overflow problem in Unicode builds
- Fixed slash typo patch.
- Do not delete no more generated doslex.c.
* Mon Jul 17 2006 mkudlvasr@suse.cz
- fixed a problem in makefiles.in and configure.in. In many cases
  the variable top_builddir was not separated by a slash. This caused
  many 'file not found' errors.
* Fri Apr  7 2006 mmarek@suse.cz
- fix array subscript out of range in src/common/db.cpp
* Thu Mar  9 2006 bk@suse.de
- Add esound-devel to BuildRequires (was implicily by SDL-devel)
- Add explicit gcc-c++ to BuildRequires (was implicit by SDL-devel)
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Feb 22 2006 sbrabec@suse.cz
- Moved pywxrc to python-wxGTK (Andreas Hanke, #152573).
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 sbrabec@suse.cz
- Package wxrc (#143258, Andreas Hanke).
- Updated README.unicode (#144090, Andreas Hanke).
- Moved bakefile to devel subpackage (#144094, Andreas Hanke).
* Mon Jan 16 2006 sbrabec@suse.cz
- Updated to version 2.6.2.1.
* Mon Sep 19 2005 sbrabec@suse.cz
- Force re-creating the old lex code in doslex.c.
* Fri Aug 19 2005 sbrabec@suse.cz
- Removed references to no more provided PangoRenderX calls.
* Mon Aug  1 2005 sbrabec@suse.cz
- Updated to version 2.6.1.0.
* Sat May 14 2005 schwab@suse.de
- Fix undefined operation.
* Wed Apr 27 2005 mcihar@suse.cz
- update to 2.6.0.0
* Fri Apr 15 2005 mcihar@suse.de
- build with system libtiff
- enabled SDL and sound support
* Wed Apr 13 2005 mcihar@suse.cz
- fix filelist
- fix build on 64-bit machines
* Tue Apr 12 2005 mcihar@suse.cz
- disable SDL support, it seems to be broken in this version
* Tue Apr 12 2005 mcihar@suse.cz
- update to 2.5.5.1
* Fri Feb  4 2005 tiwai@suse.de
- fixed the confliction of ATTRIBUTE_PRINTF* macros.
* Wed Dec 22 2004 mcihar@suse.cz
- fix python-wxGTK requires
* Fri Nov 19 2004 mcihar@suse.cz
- update to 2.5.3.1
* Wed Oct 20 2004 mcihar@suse.cz
- fixed file conflict between python-wxGTK and wxGTK-devel
* Fri Sep 17 2004 mcihar@suse.cz
- really build wxPython version against unicode wxGTK (bug #45539)
* Tue Aug 31 2004 mcihar@suse.cz
- update to 2.5.2.8
* Mon Aug 16 2004 mcihar@suse.cz
- update to 2.5.2.7
* Fri Jul 30 2004 mcihar@suse.cz
- also build non unicode libraries and ship them in wxGTK-compat package
  to allow compilation of application, that weren't written in respect
  to unicode possibility
* Wed Jun  2 2004 mcihar@suse.cz
- add missing wxPython licenses
* Thu Apr 22 2004 mcihar@suse.cz
- ${prefix} was intentional
* Wed Apr 21 2004 mcihar@suse.cz
- correct libdir on lib64
* Tue Apr 20 2004 mcihar@suse.cz
- solved conflict between wxGTK-devel and python-wxGTK
* Wed Apr 14 2004 mcihar@suse.cz
- moved sound_sdl-2.5.1.so from devel package
* Wed Apr 14 2004 mcihar@suse.cz
- build with -fPIC
- add libmspack support (enables access to MS HTML help files - *.chm)
* Tue Apr 13 2004 mcihar@suse.cz
- update to 2.5.1.5
- enable unicode support
- enabled build of contrib libraries
* Thu Mar 18 2004 mcihar@suse.cz
- make files in bin executable (bug #36331)
* Fri Mar  5 2004 mcihar@suse.cz
- little spec file cleanup, debug build can be enabled
* Wed Mar  3 2004 tiwai@suse.de
- fixed wxwin.m4 for the recent autoconf.
- moved wxwin.m4 to devel subpackage.
* Tue Jan 13 2004 mcihar@suse.cz
- enabled build with GTK 2
* Thu Oct 16 2003 mcihar@suse.cz
- do not build as root
- remove orig and rej files that should not be installed
* Wed Oct 15 2003 mcihar@suse.cz
- update to 2.4.2.4
* Fri Aug 29 2003 tiwai@suse.de
- fixed the segfault on 64bit architectures.
* Sat Aug 23 2003 ro@suse.de
- fix build on lib64
* Wed Aug 20 2003 mcihar@suse.cz
- now builds together with wxPython
- created patch for DESTDIR support
- now lives in /usr and not /usr/X11
- build all python bindings (fixes #26138 and #27349)
* Wed Jul 30 2003 adrian@suse.de
- update to version 2.4.1
- add %%run_ldconfig
* Tue May 13 2003 mmj@suse.de
- Package forgotten files
* Tue Mar  4 2003 mmj@suse.de
- Add patch to have wxFileConfigGroup::DeleteSubgroup() not seg-
  fault with pGroup == 0. Triggered by audacity but might affect
  other wxGTK programs. [#24401]
* Tue Feb 25 2003 hhetter@suse.de
- devel package requires gtk-devel (Bug Id#22479)
* Mon Feb 17 2003 hhetter@suse.de
- package gl-header files too ( Bug Id#23094 )
* Wed Jan 22 2003 meissner@suse.de
- Fixed for lib64 platforms.
* Tue Jan 14 2003 hhetter@suse.de
- updated to version 2.4.0
- updated documentation to 2.4.0 revision
- remove all outdated patches
* Tue Nov 12 2002 tcrhak@suse.cz
- fixed for bison 1.75: end rules with semicolons
* Mon Aug 12 2002 garloff@suse.de
- Fix multiple delete[] in wxHtmlTagsModule::OnExit().
* Fri Jul 26 2002 adrian@suse.de
- fix neededforbuild
* Wed May  1 2002 kukuk@suse.de
- Remove superfluous libmpeg from neededforbuild
* Fri Apr 26 2002 coolo@suse.de
- use %%_libdir
* Mon Apr 15 2002 tiwai@suse.de
- fixed build with gcc 3.1.
* Tue Feb 19 2002 hhetter@suse.de
- applied the real patch for the wxgtk-mutex performance problem
* Fri Feb 15 2002 hhetter@suse.de
- configure with --enable-std_iostreams for better support
  for C++ sources using C++ iostreams
- apply patch to fix perfomance problem with multithreaded apps
  (accepted and already in the wxGTK CVS)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 tiwai@suse.de
- updated to version 2.2.9.
- fixed neededforbuild for libwx_gtk_gl.
- added locale files to filelist.
- added --enable-soname to ensure the correct linking.
- clean up the spec file.
* Mon May  7 2001 mfabian@suse.de
- bzip2 source
* Fri Mar 30 2001 pthomas@suse.de
- Update to 2.2.6
- Renamed to wxGTK
- Split off devel package.
- Build the OpenGl add-on lib.
- Install sample code in docdir.
- Change Makefiles to use DESTDIR.
- Include both HTML and PDF Versions of the manuals.
- Eliminate warnings in C++ code.
- Build with -W -Wall -Wstrict-prototypes -Wpointer-aritth
* Fri Jan 26 2001 hhetter@suse.de
- Update to 2.2.4
* Sat Dec  9 2000 mfabian@suse.de
- Add /usr/X11R6/bin/wxgtk-config to filelist
* Sun Nov  5 2000 ro@suse.de
- fixed neededforbuild
* Fri Jun  9 2000 ro@suse.de
- up to 2.1.16
* Mon Feb 21 2000 uli@suse.de
- now builds with RPM_OPT_FLAGS
* Mon Feb 21 2000 ro@suse.de
- update to 2.1.13
- use suse_update_config macro
- patch to compile with newest gtk
* Fri Jan 14 2000 freitag@suse.de
- update to 2.1.12, URL, doc in seperate tarball
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 19 1999 kukuk@suse.de
- Add /usr/X11R6/bin/wx-config to filelist
* Tue Jul 13 1999 bs@suse.de
- use gtk and glib instead of gtkn and glibn
* Mon May 31 1999 ray@suse.de
- new package
